@@ -1,5 +1,5 @@
-from .Report import *
+from .LabReport import *
 
 __all__ = ['Report', 'ReportParagraph', 'ReportPlainContent', 'ReportTable']
-__version__ = '0.1.1'
+__version__ = '0.1.4'
 __author__ = 'Ferdinand Sukhoi'
